@@ -185,7 +185,6 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     df['time'] = df['upload_time'].apply(lambda x: humanize.naturaldelta(x))
     df = df.sort_values(by='upload_time', ascending=False)
 
-
     if target in ['0', '-1']:
         if filter: 
             df = add_metadata(df, metadata_file)
@@ -195,6 +194,15 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     else:
         df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
         df = df[['drive_time','seg_num','link']]
+        
+        # max display size
+        pd.set_option('display.max_colwidth',term_width)
+        
+        # drop duplicates in link and get max seg_num 
+        df = df.drop_duplicates(subset=['link'], keep='last')
+        df = df.sort_values(by='drive_time', ascending=False)
+        
+        # print the latest files
         print(df.head(show_n))
 
 def pull_latest(dongle_id):
