@@ -83,7 +83,7 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
     # TODO: allow for more than just 1 port setting
     target_ports = [ s['ToPort']==ports[0] for s in sg_res.ip_permissions ]
     for i in range(len(target_ports)): 
-        if i: del sg_res.ip_permissions[i]
+        if target_ports[i]: del sg_res.ip_permissions[i]
 
     
     # loop using description to only remove already existing and replace them later
